==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
var ChartSummaryDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSummaryDescriptionDescriptionMetadata, _super);
    function ChartSummaryDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSummaryDescriptionDescriptionMetadata.b = function (a) {
        if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
            ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
        }
        if (a.g(ChartSummaryDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.s(ChartSummaryDescriptionDescriptionMetadata.a);
        ProvideCalculatorEventArgsDescriptionMetadata.d(a);
    };
    ChartSummaryDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("Operand", "ExportedType:string:SummaryOperand");
        a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
        a.item("Alias", "String");
        a.item("CalculatorDisplayName", "String");
        a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
    };
    ChartSummaryDescriptionDescriptionMetadata.d = function (a) {
        ChartSummaryDescriptionDescriptionMetadata.b(a);
        a.u("ChartSummaryDescription", function () { return new ChartSummaryDescriptionDescription(); });
        a.t("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
    };
    ChartSummaryDescriptionDescriptionMetadata.$t = markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
}(Base));
export { ChartSummaryDescriptionDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
var ChartSummaryDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartSummaryDescriptionDescriptionMetadata, _super);
    function ChartSummaryDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartSummaryDescriptionDescriptionMetadata.b = function (a) {
        if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
            ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
        }
        if (a.j(ChartSummaryDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.y(ChartSummaryDescriptionDescriptionMetadata.a);
        ProvideCalculatorEventArgsDescriptionMetadata.d(a);
    };
    ChartSummaryDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("Operand", "ExportedType:string:DataSourceSummaryOperand");
        a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
        a.item("Alias", "String");
        a.item("CalculatorDisplayName", "String");
        a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
    };
    ChartSummaryDescriptionDescriptionMetadata.d = function (a) {
        ChartSummaryDescriptionDescriptionMetadata.b(a);
        a.aa("ChartSummaryDescription", function () { return new ChartSummaryDescriptionDescription(); });
        a.z("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
    };
    ChartSummaryDescriptionDescriptionMetadata.$t = markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
}(Base));
export { ChartSummaryDescriptionDescriptionMetadata };
